==> aliyun-python-sdk-ocr-1.0.9.tar.gz: aliyun-python-sdk-ocr-1.0.9/aliyunsdkocr/request/v20191230/TrimDocumentRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkocr.endpoint import endpoint_data

class TrimDocumentRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'TrimDocument','ocr')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_FileType(self):
		return self.get_body_params().get('FileType')

	def set_FileType(self,FileType):
		self.add_body_params('FileType', FileType)

	def get_FileURL(self):
		return self.get_body_params().get('FileURL')

	def set_FileURL(self,FileURL):
		self.add_body_params('FileURL', FileURL)

	def get_OutputType(self):
		return self.get_body_params().get('OutputType')

	def set_OutputType(self,OutputType):
		self.add_body_params('OutputType', OutputType)

==> aliyun-python-sdk-ocr-1.0.16.tar.gz: aliyun-python-sdk-ocr-1.0.16/aliyunsdkocr/request/v20191230/TrimDocumentRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkocr.endpoint import endpoint_data

class TrimDocumentRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'TrimDocument','ocr')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_FileType(self): # String
		return self.get_body_params().get('FileType')

	def set_FileType(self, FileType):  # String
		self.add_body_params('FileType', FileType)
	def get_OutputType(self): # String
		return self.get_body_params().get('OutputType')

	def set_OutputType(self, OutputType):  # String
		self.add_body_params('OutputType', OutputType)
	def get_FileURL(self): # String
		return self.get_body_params().get('FileURL')

	def set_FileURL(self, FileURL):  # String
		self.add_body_params('FileURL', FileURL)
